@@ -4,7 +4,7 @@
   "alpha",
   "fg", "col", "colour", "color",
   "lty", "linetype",
-  "cex", "lwd", "size",
+  "cex", "lwd", "linewidth", "size",
   "pch", "shape"
 )
 
@@ -16,8 +16,6 @@
 )
 
 # distilling functions
-first <- dplyr::first
-last <- dplyr::last
 most <- function(x) {
   x[which(factor(x) == names(which.max(table(factor(x)))))[1]]
 }
