@@ -9,11 +9,11 @@ test_that("`geom_lode` draws correctly", {
   
   skip_on_cran()
   skip_if_not_installed("vdiffr")
-  vdiffr::expect_doppelganger(
+  suppressWarnings(vdiffr::expect_doppelganger(
     "`geom_lode`: one axis",
     ggplot(d, a1) + geom_lode(aes(fill = Class, alpha = Survived)) +
       scale_x_discrete(limits = c("Class"))
-  )
+  ))
   vdiffr::expect_doppelganger(
     "`geom_lode`: lodes and alluvia",
     ggplot(d, a2) + geom_alluvium() + geom_lode()
